<?php

class DispletRetsIdxEmailController extends DispletRetsIdxPlugin {
	private function filter_message( $message ) {
		return nl2br( $message );
	}

	public function get_admin_email_address() {
		$admin_email_array = array();
		$admin_email = ( !empty( self::$_options['email'] ) ) ? self::$_options['email'] : get_option( 'admin_email' );
		if ( strpos( $admin_email, ',' ) !== false ) {
			$admin_emails = explode( ',', $admin_email );
			foreach ( $admin_emails as $email ) {
				$admin_email_array[] = trim( $email );
			}
		}
		else{
			$admin_email_array[] = $admin_email;
		}
		return $admin_email_array;
	}

	public function get_assigned_emails( $assigned_agent_id, $agent_only = false ) {
		if ( $agent_only ) {
			$assigned_email['admins_and_agent'] = array();
		}
		else{
			$assigned_email['admins_and_agent'] = self::get_admin_email_address();
		}
		$duty_agent = self::get_duty_agent( $assigned_agent_id );
		if ( !empty( $duty_agent ) && !empty( $duty_agent->user_email ) ) {
			$assigned_email['admins_and_agent'][] = $duty_agent->user_email;
			$assigned_email['address'] = $duty_agent->user_email;
			$assigned_email['name'] = ( !empty( $duty_agent->display_name ) ) ? $duty_agent->display_name : '';
		}
		else {
			$assigned_email['address'] = ( !empty( self::$_options['email_from_address'] ) ) ? self::$_options['email_from_address'] : get_option( 'admin_email' );
			$assigned_email['name'] = ( !empty( self::$_options['email_from_name'] ) ) ? self::$_options['email_from_name'] : get_bloginfo( 'name' );
		}
		return $assigned_email;
	}

	public function get_assigned_agent_id( $user_id ) {
		if ( !empty( $user_id ) ) {
			return get_user_meta( $user_id, 'displet_agent_id', true );
		}
	}

	public function get_duty_agent( $agent_id ) {
		if ( !empty( $agent_id ) ) {
			$agent = get_userdata( $agent_id );
			if ( !empty( $agent ) ) {
				return $agent;
			}
		}
	}

	private function get_headers( $assigned_email ) {
		$headers = '';
		if ( !empty( $assigned_email['address'] ) ) {
			$headers .= 'From: ';
			if ( !empty( $assigned_email['name'] ) ) {
				$headers .= $assigned_email['name'] . ' ';
			}
			$headers .= '<' . $assigned_email['address'] . '>' . PHP_EOL;
		}
		$headers .= 'Content-type: text/html; charset=iso-8859-1' . PHP_EOL;
		return $headers;
	}

	public function get_signature( $assigned_agent_id ) {
		$email_signature = false;
		if ( !empty( $assigned_agent_id ) ) {
			$email_signature = get_user_meta( $assigned_agent_id, 'displet_email_signature', true );
		}
		else if ( !empty( self::$_options['email_signature'] ) ) {
			$email_signature = self::$_options['email_signature'];
		}
		return $email_signature;
	}

	private function replace_placeholders( $template, $replacements ) {
		$template = stripslashes( $template );
		if ( empty( $replacements ) || !is_array( $replacements ) ) {
			$replacements = array();
		}
		$replacements['site_url'] = home_url();
		$replacements['site_name'] = get_bloginfo( 'name' );
		if ( !empty( $replacements ) ) {
			foreach ( $replacements as $placeholder => $replacement ) {
				$template = str_replace( '%%' . $placeholder . '%%', $replacement, $template );
			}
		}
		return $template;
	}

	public function send_assigned_lead_message( $lead_id, $assigned_agent_id ) {
		$assigned_email = self::get_assigned_emails( $assigned_agent_id, true );
		$headers = self::get_headers( $assigned_email );
		$lead = get_userdata( $lead_id );
		$email = $lead->user_email;
		$name = $lead->display_name;
		$phone = get_user_meta( $lead_id, 'displet_phone', true );
		$leads_url = admin_url( 'admin.php?page=displet-lead-manager' );
		$replacements = array(
			'user_name' => $name,
			'user_email' => $email,
			'user_phone' => $phone,
			'leads_url' => $leads_url
		 );

		// Message to admin
		if ( !empty( self::$_options['email_template_assigned_lead'] ) ) {
			$admin_message = self::$_options['email_template_assigned_lead'];
		}
		else {
			$admin_message = DispletRetsIdxEmailTemplatesModel::get_default_assigned_lead_message();
		}
		$email_signature = self::get_signature( $assigned_agent_id );
		if ( !empty( $email_signature ) ) {
			$admin_message .= PHP_EOL . PHP_EOL . $email_signature;
		}
		if ( !empty( self::$_options['email_title_assigned_lead'] ) ) {
			$admin_title = self::$_options['email_title_assigned_lead'];
		}
		else{
			$admin_title = DispletRetsIdxEmailTemplatesModel::get_default_assigned_lead_title();
		}
		wp_mail( $assigned_email['admins_and_agent'], self::replace_placeholders( $admin_title, $replacements ), self::filter_message( self::replace_placeholders( $admin_message, $replacements ) ), $headers );
	}

	public function send_email_to_friend_request() {
		check_ajax_referer( 'displet_email_friend_nonce' );

		if ( isset( $_POST['action'] ) && $_POST['action'] == 'displet_email_friend_request' ) {
			if ( !empty( $_POST['email'] ) && is_email( $_POST['email'] ) ) {
				$user_id = get_current_user_id();
				$assigned_agent_id = self::get_assigned_agent_id( $user_id );
				$assigned_email = self::get_assigned_emails( $assigned_agent_id );
				$headers = self::get_headers( $assigned_email );
				$current_user = wp_get_current_user();
				if ( !empty( $current_user->ID ) ) {
					$user = get_userdata( $current_user->ID );
					if ( !empty( $user->display_name ) ) {
						$current_user->display_name = $user->display_name;
					}
				}
				$user_name = ( !empty( $current_user->display_name ) ) ? $current_user->display_name : 'A Friend';
				$user_email = ( !empty( $current_user->user_email ) ) ? $current_user->user_email : '';
				$address = trim( $_POST['address'] ) . ', ' . trim( $_POST['city'] ) . ', ' . trim( $_POST['state'] ) . ' ' . trim( $_POST['zip'] );
				$replacements = array(
					'user_name' => $user_name,
					'user_email' => $user_email,
					'friend_name' => $_POST['name'],
					'friend_email' => $_POST['email'],
					'user_message' => $_POST['message'],
					'property_address' => $address,
					'property_url' => $_POST['url']
				 );

				// Message to admin
				if ( !empty( self::$_options['email_template_email_friend_to_admin'] ) ) {
					$admin_message = self::$_options['email_template_email_friend_to_admin'];
				}
				else {
					$admin_message = DispletRetsIdxEmailTemplatesModel::get_default_email_friend_message_to_admin();
				}
				$email_signature = self::get_signature( $assigned_agent_id );
				if ( !empty( $email_signature ) ) {
					$admin_message .= PHP_EOL . PHP_EOL . $email_signature;
				}
				if ( !empty( self::$_options['email_title_email_friend_to_admin'] ) ) {
					$admin_title = self::$_options['email_title_email_friend_to_admin'];
				}
				else {
					$admin_title = DispletRetsIdxEmailTemplatesModel::get_default_email_friend_title_to_admin();
				}
				wp_mail( $assigned_email['admins_and_agent'], self::replace_placeholders( $admin_title, $replacements ), self::filter_message( self::replace_placeholders( $admin_message, $replacements ) ), $headers );

				// Message to friend
				if ( !empty( self::$_options['email_template_email_friend_to_user'] ) ) {
					$user_message = self::$_options['email_template_email_friend_to_user'];
				}
				else {
					$user_message = DispletRetsIdxEmailTemplatesModel::get_default_email_friend_message_to_user();
				}
				if ( !empty( $email_signature ) ) {
					$user_message .= PHP_EOL . PHP_EOL . $email_signature;
				}
				if ( !empty( self::$_options['email_title_email_friend_to_user'] ) ) {
					$user_title = self::$_options['email_title_email_friend_to_user'];
				}
				else {
					$user_title = DispletRetsIdxEmailTemplatesModel::get_default_email_friend_title_to_user();
				}
				wp_mail( $_POST['email'], self::replace_placeholders( $user_title, $replacements ), self::filter_message( self::replace_placeholders( $user_message, $replacements ) ), $headers );

				echo 'Your message has been sent.';
			}
			else{
				echo 'Please enter a valid email address.';
			}
			die();
		}

		echo 'We\'re sorry, there was an error processing your request. Please try again.';
		die();
	}

	public function send_new_user_registration( $email, $name, $phone, $realtor, $url, $username, $password, $assigned_agent_id ) {
		$assigned_email = self::get_assigned_emails( $assigned_agent_id );
		$headers = self::get_headers( $assigned_email );
		$replacements = array(
			'user_name' => $name,
			'user_email' => $email,
			'user_phone' => $phone,
			'user_has_realtor' => $realtor,
			'registration_url' => $url,
			'user_username' => $username
		 );

		// Message to admin
		if ( !empty( self::$_options['email_template_new_registration_to_admin'] ) ) {
			$admin_message = self::$_options['email_template_new_registration_to_admin'];
		}
		else {
			$admin_message = DispletRetsIdxEmailTemplatesModel::get_default_new_registration_message_to_admin();
		}
		$email_signature = self::get_signature( $assigned_agent_id );
		if ( !empty( $email_signature ) ) {
			$admin_message .= PHP_EOL . PHP_EOL . $email_signature;
		}
		if ( !empty( self::$_options['email_title_new_registration_to_admin'] ) ) {
			$admin_title = self::$_options['email_title_new_registration_to_admin'];
		}
		else{
			$admin_title = DispletRetsIdxEmailTemplatesModel::get_default_new_registration_title_to_admin();
		}
		wp_mail( $assigned_email['admins_and_agent'], self::replace_placeholders( $admin_title, $replacements ), self::filter_message( self::replace_placeholders( $admin_message, $replacements ) ), $headers );

		// Message to user
		$replacements['user_password'] = $password;
		if ( !empty( self::$_options['email_template_new_registration_to_user'] ) ) {
			$user_message = self::$_options['email_template_new_registration_to_user'];
		}
		else{
			$user_message = DispletRetsIdxEmailTemplatesModel::get_default_new_registration_message_to_user();
		}
		if ( !empty( $email_signature ) ) {
			$user_message .= PHP_EOL . PHP_EOL . $email_signature;
		}
		if ( !empty( self::$_options['email_title_new_registration_to_user'] ) ) {
			$user_title = self::$_options['email_title_new_registration_to_user'];
		}
		else{
			$user_title = DispletRetsIdxEmailTemplatesModel::get_default_new_registration_title_to_user();
		}
		wp_mail( $email, self::replace_placeholders( $user_title, $replacements ), self::filter_message( self::replace_placeholders( $user_message, $replacements ) ), $headers );
	}

	public function send_property_showing_request() {
		check_ajax_referer( 'displet_property_showing_nonce' );

		if ( isset( $_POST['action'] ) && $_POST['action'] == 'displet_property_showing_request' ) {
			if ( !empty( $_POST['name'] ) && !empty( $_POST['email'] ) && ( empty( self::$_options['showing_request_require_phone'] ) || !empty( $_POST['phone'] ) ) ) {
				if ( is_email( $_POST['email'] ) ) {
					$user_id = get_current_user_id();
					$assigned_agent_id = self::get_assigned_agent_id( $user_id );
					$assigned_email = self::get_assigned_emails( $assigned_agent_id );
					$headers = self::get_headers( $assigned_email );
					$address = trim( $_POST['address'] ) . ', ' . trim( $_POST['city'] ) . ', ' . trim( $_POST['state'] ) . ' ' . trim( $_POST['zip'] );
					$replacements = array(
						'user_name' => $_POST['name'],
						'user_email' => $_POST['email'],
						'user_phone' => $_POST['phone'],
						'user_appointment' => $_POST['appointment1'],
						'user_appointment2' => $_POST['appointment2'],
						'user_message' => trim( $_POST['message'] ),
						'property_address' => $address,
						'property_url' => $_POST['url']
					 );

					// Send message to admin
					if ( !empty( self::$_options['email_template_property_showing_to_admin'] ) ) {
						$admin_message = self::$_options['email_template_property_showing_to_admin'];
					}
					else {
						$admin_message = DispletRetsIdxEmailTemplatesModel::get_default_property_showing_message_to_admin();
					}
					$email_signature = self::get_signature( $assigned_agent_id );
					if ( !empty( $email_signature ) ) {
						$admin_message .= PHP_EOL . PHP_EOL . $email_signature;
					}
					if ( !empty( self::$_options['email_title_property_showing_to_admin'] ) ) {
						$admin_title = self::$_options['email_title_property_showing_to_admin'];
					}
					else {
						$admin_title = DispletRetsIdxEmailTemplatesModel::get_default_property_showing_title_to_admin();
					}
					wp_mail( $assigned_email['admins_and_agent'], self::replace_placeholders( $admin_title, $replacements ), self::filter_message( self::replace_placeholders( $admin_message, $replacements ) ), $headers );

					// Send message to user
					if ( !empty( self::$_options['email_template_property_showing_to_user'] ) ) {
						$user_message = self::$_options['email_template_property_showing_to_user'];
					}
					else {
						$user_message = DispletRetsIdxEmailTemplatesModel::get_default_property_showing_message_to_user();
					}
					if ( !empty( $email_signature ) ) {
						$user_message .= PHP_EOL . PHP_EOL . $email_signature;
					}
					if ( !empty( self::$_options['email_title_property_showing_to_user'] ) ) {
						$user_title = self::$_options['email_title_property_showing_to_user'];
					}
					else {
						$user_title = DispletRetsIdxEmailTemplatesModel::get_default_property_showing_title_to_user();
					}
					wp_mail( $_POST['email'], self::replace_placeholders( $user_title, $replacements ), self::filter_message( self::replace_placeholders( $user_message, $replacements ) ), $headers );

					$inquiry_details = array(
						'email' => $_POST['email'],
						'name' => $_POST['name'],
						'phone' => $_POST['phone'],
						'address' => $address,
						'first_appointment' => $_POST['appointment1'],
						'second_appointment' => $_POST['appointment2'],
						'message' => $_POST['message']
					 );
					DispletRetsIdxUsersController::update_property_inquiries( $user_id, $inquiry_details );
					DispletRetsIdxUsersController::send_to_zapier( $inquiry_details, 'showing' );

					echo 'Your request has been sent.';
				}
				else{
					echo 'Please enter a valid email address.';
				}
			}
			else{
				echo 'Please complete the required fields.';
			}
			die();
		}

		echo 'We\'re sorry, there was an error processing your request. Please try again.';
		die();
	}

	public function unschedule_activity_report() {
		wp_clear_scheduled_hook( 'displetactivityreport' );
	}

	public function adjust_activity_report_schedule() {
		if ( !empty( self::$_options['email_activity'] ) ) {
			/*
			$aba = get_option( 'a_b_a', 0 );
			$aba++;
			update_option( 'a_b_a', $aba );
			*/
			wp_schedule_event( time() + 60 * 60 * 23, 'daily', 'displetactivityreport' );
		}
		else{
			/*
			$aca = get_option( 'a_c_a', 0 );
			$aca++;
			update_option( 'a_c_a', $aca );
			*/
			self::unschedule_activity_report();
		}
	}

	public function send_activity_report() {
		$current_time = current_time( 'timestamp' );
		$mostly_recent_users = get_users( array(
			'meta_key' => 'displet_last_login',
			'meta_value' => $current_time - 60 * 60 * 24 * 7,
			'meta_compare' => '>'
		 ) );
		$recent_users = array();
		if ( !empty( $mostly_recent_users ) && is_array( $mostly_recent_users ) ) {
			$edit_url = admin_url( 'user-edit.php?user_id=' );
			foreach ( $mostly_recent_users as $user ) {
				if ( !empty( $user->displet_last_login ) && is_numeric( $user->displet_last_login ) ) {
					$logins_for_day = 0;
					if ( !empty( $user->displet_logins ) && is_array( $user->displet_logins ) ) {
						foreach ( $user->displet_logins as $login ) {
							if ( $login > $current_time - 60 * 60 * 24 ) {
								$logins_for_day++;
							}
						}
					}
					$property_stats = DispletRetsIdxUsersController::get_property_view_stats( $user->displet_user_properties );
					$recent_users[] = array(
						'url' => $edit_url . $user->ID,
						'name' => $user->nickname,
						'phone' => $user->displet_phone,
						'logins_for_day' => $logins_for_day,
						'logins_total' => count( $user->displet_logins ),
						'price_average' => $property_stats['price_average'],
						'zip_mode' => $property_stats['zip_mode']
					 );
				}
			}
		}
		if ( !empty( $recent_users ) ) {
			$admin_email = self::get_admin_email_address();
			$headers = self::get_headers( false );
			$replacements = array();
			if ( !empty( self::$_options['email_title_user_activity'] ) ) {
				$title = self::$_options['email_title_user_activity'];
			}
			else {
				$title = DispletRetsIdxEmailTemplatesModel::get_default_activity_report_title();
			}
			if ( !empty( self::$_options['email_template_user_activity'] ) ) {
				$message = self::$_options['email_template_user_activity'];
			}
			else {
				$message = DispletRetsIdxEmailTemplatesModel::get_default_activity_report_message();
			}
			$replacements['user_activity_report'] = '<style>table th{font-weight: bold;} table th, table td{border: 1px solid #ccc; padding: 5px; text-align: center;} table td:first-child{text-align: left;}</style><table><tr><th>Name</th><th>Phone</th><th>Logins In Last Day</th><th>Total Logins</th><th>Average Price</th><th>Most Frequented Zip Code</th></tr>';
			foreach ( $recent_users as $user ) {
				$replacements['user_activity_report'] .= '<tr><td><a href="' . $user['url'] . '">' . $user['name'] . '</a></td><td>' . $user['phone'] . '</td><td>' . $user['logins_for_day'] . '</td><td>' . $user['logins_total'] . '</td><td>' . $user['price_average'] . '</td><td>' . $user['zip_mode'] . '</td></tr>';
			}
			$replacements['user_activity_report'] .= '</table>';
			wp_mail( $admin_email, self::replace_placeholders( $title, $replacements ), self::filter_message( self::replace_placeholders( $message, $replacements ) ), $headers );
		}
	}
}

?>