<?php

/**
 * Functions below permitted for use in external applications ( custom templates, custom theme functionality, etc. )
 *
 * All function names, parameters, and return types/values are to remain unchanged
 */

/*****************************
/ Option related
*****************************/

/**
 * @return: string
 */
function displetretsidx_get_api_key() {
	global $displetretsidx_option;
	return $displetretsidx_option['displet_app_key'];
}

/**
 * @return: string
 */
function displetretsidx_get_property_details_page_id() {
	global $displetretsidx_option;
	return $displetretsidx_option['property_details_page_id'];
}

/**
 * @return: string
 */
function displetretsidx_get_search_results_page_id() {
	global $displetretsidx_option;
	return $displetretsidx_option['search_results_page_id'];
}

/**
 * @param: $setting: string ( min_price, max_price, price_increment, beds_min, beds_max, baths_min, baths_max, min_square_feet, max_square_feet, square_feet_increment, min_acres, max_acres, or acres_increment )
 * @return: success: integer
 * @return: failure: false
 */
function displetretsidx_get_search_value( $setting ) {
	global $displetretsidx_option;
	if ( isset( $displetretsidx_option['search_values_' . $setting] ) ) {
		return intval( $displetretsidx_option['search_values_' . $setting] );
	}
	return false;
}

/**
 * @param: $field: string ( area_mls_defined, city, property_type or school_district or status )
 * @return: success: array
 * @return: failure: false
 */
function displetretsidx_get_field_options( $field ) {
	$field_option = DispletRetsIdxSettingsController::get_option( 'fields' );
	if ( isset( $field_option[$field] ) ) {
		return $field_option[$field];
	}
	return false;
}

/*****************************
/ Widget related
*****************************/

/**
 * @param: $column: integer
 * @return: boolean
 */
function displetretsidx_has_search_form( $column = 1 ) {
	$column = is_numeric( $column ) ? $column : 1;
	return DispletRetsIdxSearchFieldWidgetController::is_search_form_widget_area_used( $column );
}

/**
 * @param: $column: integer
 * @return: print: dynamic_sidebar
 */
function displetretsidx_get_search_form( $column = 1 ) {
	$column = is_numeric( $column ) ? $column : 1;
	DispletRetsIdxUtilities::get_widget_area( 'displetretsidx-search-form-' . $column, 'Displet Search Form' );
}

/**
 * @param: $column: integer
 * @return: boolean
 */
function displetretsidx_has_advanced_search_form( $column = 1 ) {
	$column = is_numeric( $column ) ? $column : 1;
	return DispletRetsIdxSearchFieldWidgetController::is_advanced_search_form_widget_area_used( $column );
}

/**
 * @param: $column: integer
 * @return: print: dynamic_sidebar
 */
function displetretsidx_get_advanced_search_form( $column = 1 ) {
	$column = is_numeric( $column ) ? $column : 1;
	DispletRetsIdxUtilities::get_widget_area( 'displetretsidx-search-form-advanced-' . $column, 'Displet Search Form - Adv. Section' );
}

/**
 * @param: $id: integer, $column: integer
 * @return: boolean
 */
function displetretsidx_has_quick_search_form( $id, $column = 1 ) {
	$id = is_numeric( $id ) ? $id : 1;
	$column = is_numeric( $column ) ? $column : 1;
	return DispletRetsIdxSearchFieldWidgetController::is_quick_search_form_column_used( $id, $column );
}

/**
 * @param: $id: integer, $column: integer
 * @return: print: dynamic_sidebar
 */
function displetretsidx_get_quick_search_form( $id, $column = 1 ) {
	$id = is_numeric( $id ) ? $id : 1;
	$column = is_numeric( $column ) ? $column : 1;
	DispletRetsIdxUtilities::get_widget_area( 'displetretsidx-quick-search-' . $id . '-form-' . $column, 'Displet Quick Search ' . $id . ' Form' );
}

/*****************************
/ Listings related
*****************************/

/**
 * @param: $criteria: array( 'field' => 'value' ); $num_listings: integer, 1-50
 * @return: success - array: $results['listings'] = object( stdClass ), $results['meta'] = object( stdClass ), $results['query_url'] = string
 * @return: failure - boolean: false
 */
function displetretsidx_get_listings( $criteria = array(), $num_listings = false ) {
	if ( !empty( $num_listings ) ) {
		$criteria['num_listings'] = $num_listings;
	}
	$residentials = new DispletRetsIdxResidentials( $criteria );
	$results = $residentials->get_residentials();
	if ( !empty( $results ) ) {
		return array(
			'listings' => $results['listings'],
			'meta' => $results['meta'],
			'query_url' => $results['query_url'],
		 );
	}
	return false;
}

/**
 * @param: $criteria: array( 'field' => 'value' )
 * @return: success - integer
 * @return: failure - boolean: false
 */
function displetretsidx_get_count( $criteria = false ) {
	$residentials = new DispletRetsIdxResidentials( $criteria );
	$count = $residentials->get_count();
	if ( !empty( $count ) || $count === 0 ) {
		return $count;
	}
	return false;
}

/**
 * @param: $criteria: array( 'field' => 'value' )
 * @return: success - array() of query args
 * @return: failure - boolean: false
 */
function displetretsidx_get_query_args( $criteria = false ) {
	$residentials = new DispletRetsIdxResidentials( $criteria );
	$args = $residentials->get_query_args();
	if ( !empty( $args ) ) {
		return $args;
	}
	return false;
}

?>