<?php

class DispletRetsIdxResidentialsModel extends DispletRetsIdxPlugin {
	protected $_model;
	protected $_query_args;
	protected $_residentials = array();

	protected static $_default_return_fields = array(
		'city',
		'full_baths',
		'half_baths',
		'id',
		'internet_remarks',
		'latitude',
		'list_price',
		'longitude',
		'num_bedrooms',
		'primary_big_image_urls',
		'property_type',
		'state',
		'status',
		'street_name',
		'street_number',
		'street_post_dir',
		'street_pre_direction',
		'square_feet',
		'unit',
		'zip',
	);

	protected static $_required_residential_return_fields = array(
		'city',
		'id',
		'state',
		'street_name',
		'street_number',
		'street_post_dir',
		'street_pre_direction',
		'unit',
		'zip',
	);

	protected static $_search_fields = array(
		'area_mls_defined',
		'basement',
		'city',
		'county',
		'id',
		'is_foreclosure',
		'is_gated_community',
		'keyword',
		'listed_since',
		'last_modified',
		'listing_agent_id',
		'listing_office_id',
		'master_on_main',
		'max_bathrooms',
		'max_bedrooms',
		'max_list_price',
		'max_price_per_sq_feet',
		'max_square_feet',
		'max_square_feet_available',
		'min_acres',
		'min_bathrooms',
		'min_bedrooms',
		'min_list_price',
		'min_lot_size',
		'min_price_per_sq_feet',
		'min_square_feet',
		'min_square_feet_available',
		'min_stories',
		'mls_number',
		'pool_on_property',
		'property_type',
		'quick_terms',
		'school',
		'school_district',
		'short_sale',
		'status',
		'street_name',
		'street_number',
		'subdivision',
		'waterfront',
		'year_built',
		'zip',
	);

	private function build_query_args() {
		$this->maybe_set_return_fields();
		$this->maybe_set_search_fields();
		$this->maybe_set_property_filter();
		$this->set_sort();
	}

	protected function get_return_fields() {
		$return_fields = self::$_default_return_fields;
		if ( !empty( self::$_options['include_subdivision'] ) ) {
			$return_fields[] = 'subdivision';
		}
		if ( !empty( self::$_options['include_mls_number'] ) ) {
			$return_fields[] = 'mls_number';
		}
		if ( !empty( self::$_options['include_listing_agent'] ) ) {
			$return_fields[] = 'listing_agent_name';
		}
		if ( !empty( self::$_options['include_listing_office'] ) ) {
			$return_fields[] = 'listing_office_name';
		}
		if ( !empty( self::$_options['include_listing_agent'] ) ) {
			$return_fields[] = 'listing_agent_name';
		}
		return $return_fields;
	}

	private function maybe_filter_city() {
		if ( !empty( self::$_options['city_include_filter'] ) && is_array( self::$_options['city_include_filter'] ) ) {
			$city_filter = array_filter( self::$_options['city_include_filter'], array( 'DispletRetsIdxSearchFieldWidgetController', 'property_type_array_filter_callback' ) );
		}
		if ( !empty( $city_filter ) ) {
			$filter_cities = self::$_options['city_include_filter'];
			if ( !empty( $this->_query_args['city'] ) ){
				$model_cities = explode( ',', $this->_query_args['city'] );
				foreach ( $model_cities as $model_city ) {
					foreach ( $filter_cities as $filter_city_key => $filter_city_value ) {
						if ( $filter_city_value == 'true' && strpos( strtolower( $filter_city_key ), strtolower( $model_city ) ) !== false ) {
							$query_cities[] = $model_city;
						}
					}
				}
				if ( !empty( $query_cities ) ) {
					$this->_query_args['city'] = implode( ',', $query_cities );
				}
				else{
					$this->_query_args['city'] = 'property_filter_excluded';
				}
			}
			else{
				foreach ( $filter_cities as $city_key => $city_value ) {
					if ( $city_value == 'true' ) {
						$query_cities[] .= $city_key;
					}
				}
				if ( !empty( $query_cities ) ) {
					$this->_query_args['city'] = implode( ',', $query_cities );
				}
			}
		}
	}

	private function maybe_filter_min_price() {
		if ( !empty( self::$_options['min_price_filter'] ) && is_numeric( self::$_options['min_price_filter'] ) ) {
			$min_price = intval( self::$_options['min_price_filter'] );
			if ( empty( $this->_query_args['min_list_price'] ) || $this->_query_args['min_list_price'] < $min_price ){
				$this->_query_args['min_list_price'] = $min_price;
			}
		}
	}

	private function maybe_filter_max_price() {
		if ( !empty( self::$_options['max_price_filter'] ) && is_numeric( self::$_options['max_price_filter'] ) ) {
			$max_price = intval( self::$_options['max_price_filter'] );
			if ( empty( $this->_query_args['max_list_price'] ) || $this->_query_args['max_list_price'] < $max_price ){
				$this->_query_args['max_list_price'] = $max_price;
			}
		}
	}

	private function maybe_filter_property_type() {
		if ( !empty( self::$_options['property_type_include_filter'] ) ) {
			$property_type_filter = array_filter( self::$_options['property_type_include_filter'], array( 'DispletRetsIdxSearchFieldWidgetController', 'property_type_array_filter_callback' ) );
		}
		if ( !empty( $property_type_filter ) ) {
			$filter_property_types = self::$_options['property_type_include_filter'];
			if ( !empty( $this->_query_args['property_type'] ) ){
				$model_property_types = explode( ',', $this->_query_args['property_type'] );
				foreach ( $model_property_types as $model_property_type ) {
					foreach ( $filter_property_types as $filter_property_type_key => $filter_property_type_value ) {
						if ( $filter_property_type_value == 'true' && strpos( strtolower( $filter_property_type_key ), strtolower( $model_property_type ) ) !== false ) {
							$query_property_types[] = $model_property_type;
						}
					}
				}
				if ( !empty( $query_property_types ) ) {
					$this->_query_args['property_type'] = implode( ',', $query_property_types );
				}
				else{
					$this->_query_args['property_type'] = 'property_filter_excluded';
				}
			}
			else{
				foreach ( $filter_property_types as $property_type_key => $property_type_value ) {
					if ( $property_type_value == 'true' ) {
						$query_property_types[] .= $property_type_key;
					}
				}
				if ( !empty( $query_property_types ) ) {
					$this->_query_args['property_type'] = implode( ',', $query_property_types );
				}
			}
		}
	}

	private function maybe_filter_zip_code() {
		if ( !empty( self::$_options['zip_code_include_filter'] ) ) {
			$filter_zips = array_map( 'trim', explode( "\n", self::$_options['zip_code_include_filter'] ) );
			if ( !empty( $this->_query_args['zip'] ) ){
				$model_zips = explode( ',', $this->_query_args['zip'] );
				foreach ( $model_zips as $model_zip ) {
					foreach ( $filter_zips as $filter_zip ) {
						if ( strpos( $filter_zip, $model_zip ) !== false ) {
							$query_zips[] = $model_zip;
						}
					}
				}
				if ( !empty( $query_zips ) ) {
					$this->_query_args['zip'] = implode( ',', $query_zips );
				}
				else{
					$this->_query_args['zip'] = 'property_filter_excluded';
				}
			}
			else{
				$this->_query_args['zip'] = implode( ',', $filter_zips );
			}
		}
	}

	private function maybe_set_property_filter() {
		$this->maybe_filter_city();
		$this->maybe_filter_min_price();
		$this->maybe_filter_max_price();
		$this->maybe_filter_property_type();
		$this->maybe_filter_zip_code();
	}

	private function maybe_set_return_fields() {
		if ( $this->_model['is_displet_api'] && !empty( $this->_model['return_fields'] ) && is_array( $this->_model['return_fields'] ) ) {
			if ( $this->_model['get_residentials'] || $this->_model['get_listings_by_status'] ) {
				foreach ( self::$_required_residential_return_fields as $return_field ) {
					if ( empty( $this->_model['return_fields'][ $return_field ] ) ) {
						$this->_model['return_fields'][] = $return_field;
					}
				}
			}
			if ( $this->_model['layout'] === 'table' ) {
				$this->_model['return_fields'][] = 'year_built';
			}
			$this->_query_args['return_fields'] = implode( ',', array_unique( $this->_model['return_fields'] ) );
		}
	}

	private function maybe_set_search_fields() {
		foreach ( self::$_search_fields as $search_field ) {
			if ( !empty( $this->_model[ $search_field ] ) ) {
				$this->_query_args[ $search_field ] = $this->_model[ $search_field ];
			}
		}
	}

	private function set_sort() {
		if ( !empty( $this->_model['sort_by'] ) && !empty( $this->_model['direction'] ) ) {
			$this->_query_args['sort_by'] = $this->_model['sort_by'];
			$this->_query_args['direction'] = $this->_model['direction'];
		}
		else{
			if ( self::$_options['listings_sort'] === 'price-ascending' ) {
				$this->_query_args['sort_by'] = 'list_price';
				$this->_query_args['direction'] = 'asc';
			}
			else if ( self::$_options['listings_sort'] === 'list-date-ascending' ) {
				$this->_query_args['sort_by'] = 'list_date';
				$this->_query_args['direction'] = 'asc';
			}
			else if ( self::$_options['listings_sort'] === 'list-date-descending' ) {
				$this->_query_args['sort_by'] = 'list_date';
				$this->_query_args['direction'] = 'desc';
			}
			else {
				$this->_query_args['sort_by'] = 'list_price';
				$this->_query_args['direction'] = 'desc';
			}
		}
	}

	private function get_property_details_page_url() {
		if ( $this->_model['is_mobile_page'] ) {
			$this->_model['property_details_page_url'] = home_url( 'rets-mobile' );
		}
		else {
			$this->_model['property_details_page_url'] = get_permalink( self::$_options['property_details_page_id'] );
		}
	}

	protected function prep_query() {
		$this->get_property_details_page_url();
		$this->build_query_args();
		$this->set_endpoint();
	}

	private function set_endpoint() {
		if ( $this->_model['extended_stats'] ) {
			$this->_model['endpoint'] = 'extended_stats';
		}
	}
}

?>